# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/01_envs_inventory/10_single_period_envs.ipynb.

# %% auto 0
__all__ = ['foo']

# %% ../../nbs/01_envs_inventory/10_single_period_envs.ipynb 3
def foo(): pass
